<template>
    <div class="ptz-controls" :class="{ 'show': isPtzControlVisible }">
      <div class="control-title">云台控制</div>
      <div class="ptz-buttons">
        <el-button class="ptz-up" @click="controlPTZ('UP')">
          <i class="el-icon-arrow-up"></i>
        </el-button>
        <div class="ptz-middle">
          <el-button class="ptz-left" @click="controlPTZ('LEFT')">
            <i class="el-icon-arrow-left"></i>
          </el-button>
          <el-button class="ptz-stop" @click="controlPTZ('STOP')">
            <i class="el-icon-video-pause"></i>
          </el-button>
          <el-button class="ptz-right" @click="controlPTZ('RIGHT')">
            <i class="el-icon-arrow-right"></i>
          </el-button>
        </div>
        <el-button class="ptz-down" @click="controlPTZ('DOWN')">
          <i class="el-icon-arrow-down"></i>
        </el-button>
      </div>
      <div class="speed-control">
        <span>速度: {{ ptzSpeed }}</span>
        <el-slider 
          v-model="ptzSpeed" 
          :min="1" 
          :max="7" 
          :step="1"
          :show-tooltip="false"
        ></el-slider>
      </div>
      </div>
</template>

<script>
import { ptzController } from '@/utils/ptzControl'

export default {
  name: 'FLVPlayer',
  props: {
    isPtzControlVisible: {
      type: Boolean,
      required: true
    },
    stream: {
      type: Object,
      default: () => ({})
    }
  },
   data() {
        return {
            ptzSpeed: 3,
        }
    },

  methods: {
     /**
     * 控制云台方向
     * @param {string} action - 控制动作：'UP'|'DOWN'|'LEFT'|'RIGHT'|'STOP'|'FOCUS_NEAR'|'IN'|'OUT'
     */
    controlPTZ(action) {
      ptzController.startPtzControl({
        direction: action.toUpperCase(),
        stream: this.stream,
        onSuccess: () => {
          console.log('云台控制成功:', action);
        },
        onError: (error) => {
          console.error('云台控制失败:', error);
          this.$message.error(error.message);
        }
      });
    },
    /**
     * 设置云台速度
     * @param {number} speed - 速度值(1-7)
     */
    setPtzSpeed(speed) {
      ptzController.setPtzSpeed(speed);
    },

    /**
     * 获取当前云台速度
     * @returns {number} 当前速度值
     */
    getPtzSpeed() {
      return ptzController.getPtzSpeed();
    },
   
  }
}
</script>

<style scoped>
/* 云台控制样式 */
.ptz-controls {
  position: fixed;
  right: -200px; /* 初始状态隐藏 */
  top: 50%;
  transform: translateY(-50%);
  background: rgba(0, 0, 0, 0.85);
  padding: 20px;
  border-radius: 16px 0 0 16px;
  z-index: 1000;
  backdrop-filter: blur(10px);
  box-shadow: -4px 0 20px rgba(0, 0, 0, 0.4);
  transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1);
  width: 200px;
  border: 1px solid rgba(255, 255, 255, 0.1);
}

.ptz-controls.show {
  right: 0;
}

/* 云台控制触发按钮 */
.ptz-trigger {
  position: fixed;
  right: 0;
  top: 50%;
  transform: translateY(-50%);
  background: #409EFF;
  color: white;
  padding: 12px;
  border-radius: 8px 0 0 8px;
  cursor: pointer;
  z-index: 999;
  box-shadow: -2px 0 8px rgba(0, 0, 0, 0.2);
  transition: all 0.3s ease;
  writing-mode: vertical-lr;
  text-orientation: upright;
  font-size: 14px;
  letter-spacing: 2px;
  display: flex;
  align-items: center;
  gap: 8px;
}

.ptz-trigger:hover {
  background: #66b1ff;
  padding-right: 16px;
}

.ptz-trigger.hide {
  right: 180px;
}

.ptz-buttons {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 8px;
}

.ptz-middle {
  display: flex;
  gap: 8px;
  margin: 8px 0;
}
.ptz-stop {
  background-color: #f56c6c;
  color: white;
}
.ptz-controls .el-button {
  padding: 10px;
  min-width: 44px;
  height: 44px;
  border-radius: 8px;
  background: rgba(255, 255, 255, 0.15);
  border: 1px solid rgba(255, 255, 255, 0.25);
  color: #fff;
  transition: all 0.2s;
}

.ptz-controls .el-button:hover {
  background: rgba(255, 255, 255, 0.25);
  transform: translateY(-2px);
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
}

.ptz-controls .el-button:active {
  background: rgba(255, 255, 255, 0.35);
  transform: translateY(0);
}

</style>